pg.ddx.io  pgsql-performance@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Tom Lane <tgl@sss.pgh.pa.us>
To: Vladimir Kamarzin <vvk@vvk.pp.ru>
Cc: pgsql-performance@postgresql.org
Subject: Re: Performance degradation in 324577f39bc8738ed0ec24c36c5cb2c2f81ec660
Date: Tue, 07 Oct 2014 09:56:34 -0400
Message-ID: <22483.1412690194@sss.pgh.pa.us> (raw)
In-Reply-To: <29191412676815@web25o.yandex.ru>
References: <29191412676815@web25o.yandex.ru>
List-Unsubscribe:  <mailto:majordomo@postgresql.org?body=unsub%20pgsql-performance>

Vladimir Kamarzin <vvk@vvk.pp.ru> writes:
> After upgrade from 9.3.1 to 9.3.5 we expirienced a slight performance degradation of all queries. Query time increased to some amount of ms, mostly in range of 100ms. Some actions in our application results in a lot of small queries and in such cases performance degradation is very significant - total action performs for a 2-3 times longer then before (15s -> 40s, etc).
> Using git-bisect we've found a bad revision causes performance drop: it is 324577f39bc8738ed0ec24c36c5cb2c2f81ec660

Hm.  If you're going to do queries that involve update/delete across large
inheritance trees, that bug fix is unavoidably going to cost you some
cycles.  Having said that, though, the append_rel_list data structures
aren't especially large or complex, so it's a mite astonishing that you
could notice this extra copying cost in the context of everything else
that happens in a large inherited UPDATE.  I am wondering if you've
misidentified the commit that made the difference --- especially since you
claim there's a penalty for "all" queries, which there manifestly couldn't
be with this particular patch.  If not, there must be something rather
unusual about your queries or schema.  Care to provide a self-contained
test case?

			regards, tom lane


-- 
Sent via pgsql-performance mailing list (pgsql-performance@postgresql.org)
To make changes to your subscription:
http://www.postgresql.org/mailpref/pgsql-performance



view thread (3+ messages)  latest in thread

Message-ID: <22483.1412690194@sss.pgh.pa.us>
Permalink:  ../22483.1412690194@sss.pgh.pa.us/
Also on:    postgresql.org/message-id/22483.1412690194@sss.pgh.pa.us

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-performance@postgresql.org
  Cc: tgl@sss.pgh.pa.us, vvk@vvk.pp.ru
  Subject: Re: Performance degradation in 324577f39bc8738ed0ec24c36c5cb2c2f81ec660
  In-Reply-To: <22483.1412690194@sss.pgh.pa.us>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox